#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#line 3 "lex.priv_gst_parse_yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 0
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE priv_gst_parse_yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via priv_gst_parse_yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void priv_gst_parse_yyrestart (FILE *input_file ,yyscan_t yyscanner );
void priv_gst_parse_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE priv_gst_parse_yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void priv_gst_parse_yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void priv_gst_parse_yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void priv_gst_parse_yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void priv_gst_parse_yypop_buffer_state (yyscan_t yyscanner );

static void priv_gst_parse_yyensure_buffer_stack (yyscan_t yyscanner );
static void priv_gst_parse_yy_load_buffer_state (yyscan_t yyscanner );
static void priv_gst_parse_yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER priv_gst_parse_yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE priv_gst_parse_yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE priv_gst_parse_yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE priv_gst_parse_yy_scan_bytes (yyconst char *bytes,yy_size_t len ,yyscan_t yyscanner );

void *priv_gst_parse_yyalloc (yy_size_t ,yyscan_t yyscanner );
void *priv_gst_parse_yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void priv_gst_parse_yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer priv_gst_parse_yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        priv_gst_parse_yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            priv_gst_parse_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        priv_gst_parse_yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            priv_gst_parse_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define priv_gst_parse_yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 11
#define YY_END_OF_BUFFER 12
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[185] =
    {   0,
        0,    0,    0,    0,   12,   10,    9,    9,    6,   10,
        8,    8,   10,    5,    5,    5,    5,    8,   11,    9,
        0,    0,    0,    2,    7,    7,    7,    7,    0,    5,
        3,    0,    0,    5,    3,    5,    0,    2,    7,    0,
        7,    7,    7,    0,    7,    7,    7,    0,    0,    4,
        3,    1,    0,    1,    1,    1,    0,    3,    0,    0,
        7,    0,    7,    7,    7,    0,    7,    7,    7,    3,
        1,    0,    1,    1,    0,    1,    1,    1,    3,    3,
        7,    0,    0,    6,    0,    0,    6,    0,    0,    7,
        7,    1,    0,    1,    1,    0,    1,    1,    7,    7,

        7,    7,    0,    0,    0,    6,    0,    0,    0,    0,
        0,    0,    0,    6,    0,    0,    1,    1,    7,    0,
        7,    7,    0,    7,    7,    7,    0,    0,    0,    7,
        0,    7,    7,    0,    7,    7,    0,    0,    7,    7,
        0,    0,    0,    0,    0,    6,    0,    0,    0,    0,
        0,    6,    0,    0,    0,    0,    6,    0,    0,    0,
        0,    0,    6,    0,    0,    0,    0,    0,    6,    0,
        0,    0,    0,    0,    6,    0,    0,    0,    0,    0,
        0,    0,    0,    0
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    6,    1,    7,    8,
        9,    1,   10,   11,   12,   13,   14,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   16,   17,    1,
       18,    1,    1,    1,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
        1,   20,    1,    1,   21,    1,   19,   19,   19,   22,

       22,   22,   19,   19,   22,   19,   19,   19,   19,   22,
       19,   19,   19,   22,   19,   22,   19,   19,   19,   19,
       19,   19,   23,    1,   23,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[24] =
    {   0,
        1,    2,    3,    1,    1,    4,    1,    1,    1,    5,
        5,    6,    7,    8,    9,   10,    1,   11,    9,    1,
       12,    9,    1
    } ;

static yyconst flex_uint16_t yy_base[227] =
    {   0,
        0,    0,    0,    0,  212, 1783,   22,   24,   26,  197,
     1783,  194,   25,   44,   61,   82,  189,  187, 1783,   31,
       33,  185,   32,    0,  174,   99,  118,   29,  137,  179,
      154,  175,  176,    0,  194,  177,    0,    0,  215,   33,
      170,  234,  253,   34,  272,  165,   38,   40,   48, 1783,
        0,   58,  291,  310,  329,   66,  165,  344,  160,  366,
     1783,   39,  388,  407,  426,   68,  445,  464,  483,    0,
      502,   50,   87,  521,   74,   89,   95,   67,    0,  158,
       98,  530,  541, 1783,  562,    0,  571,   63,  592,   88,
       92, 1783,  106,  611,  111,  103,  630,  114,  150,  649,

      668,  104,  677,  688,  709,  718,  739,  760,  125,  140,
      769,  780,    0,  791,    0,    0,  117,  122,  812,  125,
      133,  831,  126,  141,  131,  139,    0,  146,    0, 1783,
      127,  850,  161,  145,  869,  164,  878,  900,  163,  151,
      923,  935,  946,  967,    0,  976,  997, 1006, 1017, 1038,
        0, 1047, 1068, 1077, 1088, 1109, 1118, 1139, 1160, 1169,
     1180,    0, 1191,    0,    0, 1202, 1213, 1234, 1243, 1264,
     1285, 1294, 1305,    0, 1316,    0,    0,    0,  184,    0,
      186,    0,    0, 1783, 1338, 1349, 1351, 1363, 1374, 1381,
     1387, 1399, 1411, 1423, 1435, 1443, 1448, 1457, 1469, 1481,

     1493, 1502, 1514, 1526, 1538, 1550, 1562, 1574, 1586, 1598,
     1610, 1621, 1630, 1642, 1654, 1666, 1673, 1682, 1694, 1706,
     1718, 1725, 1734, 1746, 1758, 1770
    } ;

static yyconst flex_int16_t yy_def[227] =
    {   0,
      184,    1,  185,  185,  184,  184,  184,  184,  186,  184,
      184,  187,  188,  189,  184,  189,   15,  184,  184,  184,
      186,  190,  188,  191,  188,  192,  193,  194,  184,   16,
      184,  195,  196,   15,  184,   16,  197,  191,  192,  198,
      188,  199,  193,  200,  201,  188,  194,  184,  184,  184,
      202,  195,  195,  203,  204,  205,  184,  184,  184,  184,
      184,  198,  192,  192,  199,  200,  193,  193,  201,  202,
      203,  206,  207,  204,  208,  209,  195,  205,   58,  202,
      210,   60,   60,  184,  211,   60,   60,  212,  213,  198,
      200,  184,  206,  203,  207,  208,  204,  209,  210,  214,

      215,  216,   60,   60,  211,   60,   60,  213,  212,  217,
       60,   60,  105,   60,  107,  108,  206,  208,  214,  218,
      219,  215,  220,  221,  210,  216,  107,  107,  222,  184,
      218,  214,  219,  220,  215,  221,   60,  184,  218,  220,
      184,  138,  138,  223,  138,  138,  224,  141,  141,  225,
      141,  141,  226,  138,  138,  223,  138,  138,  224,  138,
      138,  156,  138,  158,  159,  141,  141,  225,  141,  141,
      226,  141,  141,  168,  141,  170,  171,  158,  158,  170,
      170,  138,  141,    0,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,

      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184
    } ;

static yyconst flex_uint16_t yy_nxt[1807] =
    {   0,
        6,    7,    8,    9,   10,    6,    6,   11,   11,    6,
       11,    6,   12,   13,   14,    9,   11,   11,   15,    6,
       16,   17,   18,   20,   20,   20,   20,   21,   21,   26,
       25,   27,   20,   20,   21,   21,   26,   61,   27,   25,
       61,   49,   49,   90,   28,   29,   29,   50,   47,   49,
       49,   28,   62,   66,   92,   50,   31,   47,   62,  184,
      184,   32,   29,   29,  109,  109,   30,   52,   52,   93,
       33,   33,   34,   35,   91,   34,   36,   56,   32,   34,
       92,   30,   34,   29,   29,   78,   78,   66,   71,   72,
       74,   75,   61,   96,   31,   23,  184,  184,   61,   32,

       40,   40,  100,   41,  101,   99,   95,   62,   98,  118,
      117,   66,   71,   72,   56,   74,   75,  102,   42,   44,
       44,   92,   96,  126,   41,   93,  109,  109,   92,  130,
       95,  139,  130,   98,  119,  120,   93,   45,   29,   29,
       99,   96,  122,  123,  131,  134,  131,   83,   83,   48,
      102,  140,  133,  129,   32,   49,   49,  130,  126,  137,
      136,   50,  119,  120,  134,  122,  123,  130,   51,  102,
      134,   59,   51,   81,   51,   51,   53,   53,   59,   54,
      133,   55,  131,  136,   28,  143,  143,  149,  149,   28,
       59,   57,  184,   28,   56,   49,   49,  182,   37,  183,

       23,   50,   23,   33,   33,   33,   33,   23,   58,   57,
       23,  184,   58,  184,   51,   58,   40,   40,  184,   41,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,   42,   39,   40,  184,   64,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,   65,   44,   44,  184,  184,  184,   41,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  184,   45,   43,   44,  184,  184,  184,   68,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      184,   69,   53,   53,  184,   54,  184,   55,  184,  184,

      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
       56,   72,   72,  184,   52,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,   73,
       75,   75,  184,  184,  184,   52,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,   76,   70,
      184,  184,  184,   33,   33,   79,   33,  184,   79,   80,
      184,  184,   79,  184,   70,   79,   82,   83,   83,   84,
       82,   82,   82,   82,   82,   82,   85,   86,   82,   82,
       86,   87,   88,   82,   86,   89,   82,   86,   82,   40,
       40,  184,   41,  184,  184,  184,  184,  184,  184,  184,

      184,  184,  184,  184,  184,  184,  184,   42,   40,   40,
      184,   41,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,   42,   39,   40,  184,
       64,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,   65,   44,   44,  184,  184,
      184,   41,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,   45,   44,   44,  184,  184,  184,
       41,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,   45,   43,   44,  184,  184,  184,   68,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,

      184,  184,   69,   72,   72,  184,   52,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      184,   73,   75,   75,  184,  184,  184,   52,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
       76,   82,  184,  184,   82,  184,  184,  184,   82,  184,
      184,   82,   82,  184,  184,   82,  184,  184,  184,   82,
      184,  184,   82,  104,  104,   84,  184,  184,  184,  184,
      184,  184,  105,  184,  184,  184,  184,  106,  107,  184,
      184,  108,   82,  184,  184,   82,  184,  184,  184,   82,
      184,  184,   82,  112,   83,   87,  184,  184,  184,  184,

      184,  184,  113,  184,  184,  184,  184,  114,  115,  184,
      184,  116,   72,   72,  184,   52,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
       73,   75,   75,  184,  184,  184,   52,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,   76,
      120,  120,  184,   99,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  121,  123,
      123,  184,  184,  184,   99,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  124,   82,  184,
      184,   82,  184,  184,  184,   82,  184,  184,   82,   82,

      184,  184,   82,  184,  184,  184,   82,  184,  184,   82,
      104,  104,   84,  184,  184,  184,  184,  184,  184,  105,
      184,  184,  184,  184,  106,  107,  184,  184,  108,   82,
      184,  184,   82,  184,  184,  184,   82,  184,  184,   82,
      127,  127,  184,  184,  184,  184,  184,  184,  184,  184,
      128,  184,  184,  128,  184,  184,  184,  128,  184,  184,
      128,  112,   83,   87,  184,  184,  184,  184,  184,  184,
      113,  184,  184,  184,  184,  114,  115,  184,  184,  116,
       82,  184,  184,   82,  184,  184,  184,   82,  184,  184,
       82,   82,  184,  184,   82,  184,  184,  184,   82,  184,

      184,   82,   82,  184,  184,   82,  184,  184,  184,   82,
      184,  184,   82,  120,  120,  184,   99,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  121,  123,  123,  184,  184,  184,   99,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,
      124,  120,  120,  184,   99,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  121,
      123,  123,  184,  184,  184,   99,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  124,  141,
      184,  184,  141,  184,  184,  184,  141,  184,  184,  141,

      142,  143,  143,   84,  142,  142,  142,  142,  142,  142,
      144,  145,  142,  142,  145,  146,   88,  142,  145,  147,
      142,  145,  142,  148,  149,  149,   84,  148,  148,  148,
      148,  148,  148,  150,  151,  148,  148,  151,  152,   88,
      148,  151,  153,  148,  151,  148,  142,  184,  184,  142,
      184,  184,  184,  142,  184,  184,  142,  142,  184,  184,
      142,  184,  184,  184,  142,  184,  184,  142,  155,  155,
       84,  184,  184,  184,  184,  184,  184,  156,  184,  184,
      184,  184,  157,  158,  184,  184,  159,  142,  184,  184,
      142,  184,  184,  184,  142,  184,  184,  142,  161,  143,

      146,  184,  184,  184,  184,  184,  184,  162,  184,  184,
      184,  184,  163,  164,  184,  184,  165,  148,  184,  184,
      148,  184,  184,  184,  148,  184,  184,  148,  148,  184,
      184,  148,  184,  184,  184,  148,  184,  184,  148,  167,
      167,   84,  184,  184,  184,  184,  184,  184,  168,  184,
      184,  184,  184,  169,  170,  184,  184,  171,  148,  184,
      184,  148,  184,  184,  184,  148,  184,  184,  148,  173,
      149,  152,  184,  184,  184,  184,  184,  184,  174,  184,
      184,  184,  184,  175,  176,  184,  184,  177,  142,  184,
      184,  142,  184,  184,  184,  142,  184,  184,  142,  142,

      184,  184,  142,  184,  184,  184,  142,  184,  184,  142,
      155,  155,   84,  184,  184,  184,  184,  184,  184,  156,
      184,  184,  184,  184,  157,  158,  184,  184,  159,  142,
      184,  184,  142,  184,  184,  184,  142,  184,  184,  142,
      178,  178,  184,  184,  184,  184,  184,  184,  184,  184,
      179,  184,  184,  179,  184,  184,  184,  179,  184,  184,
      179,  161,  143,  146,  184,  184,  184,  184,  184,  184,
      162,  184,  184,  184,  184,  163,  164,  184,  184,  165,
      142,  184,  184,  142,  184,  184,  184,  142,  184,  184,
      142,  142,  184,  184,  142,  184,  184,  184,  142,  184,

      184,  142,  142,  184,  184,  142,  184,  184,  184,  142,
      184,  184,  142,  148,  184,  184,  148,  184,  184,  184,
      148,  184,  184,  148,  148,  184,  184,  148,  184,  184,
      184,  148,  184,  184,  148,  167,  167,   84,  184,  184,
      184,  184,  184,  184,  168,  184,  184,  184,  184,  169,
      170,  184,  184,  171,  148,  184,  184,  148,  184,  184,
      184,  148,  184,  184,  148,  180,  180,  184,  184,  184,
      184,  184,  184,  184,  184,  181,  184,  184,  181,  184,
      184,  184,  181,  184,  184,  181,  173,  149,  152,  184,
      184,  184,  184,  184,  184,  174,  184,  184,  184,  184,

      175,  176,  184,  184,  177,  148,  184,  184,  148,  184,
      184,  184,  148,  184,  184,  148,  148,  184,  184,  148,
      184,  184,  184,  148,  184,  184,  148,  148,  184,  184,
      148,  184,  184,  184,  148,  184,  184,  148,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       22,   22,  184,  184,   22,  184,  184,   22,   24,   24,
      184,  184,   24,   25,  184,  184,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   30,   30,   30,  184,   30,
       30,  184,   30,   30,   30,   30,   22,  184,   22,   22,
       38,  184,   38,  184,  184,   38,   38,  184,   38,   39,

       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   46,   46,  184,   46,   46,   46,   46,
       46,   46,   46,   46,   46,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   33,   33,   33,
      184,   33,   33,   60,  184,  184,   60,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   63,
       63,   63,   63,   63,   63,   63,   63,   63,   63,   63,
       63,   44,   44,   44,   44,   44,   44,   44,   44,   44,
       44,   44,   44,   67,   67,   67,   67,   67,   67,   67,

       67,   67,   67,   67,   67,   70,  184,   70,  184,  184,
       70,   70,  184,   70,   71,   71,   71,   71,   71,   71,
       71,   71,   71,   71,   71,   71,   74,   74,   74,   74,
       74,   74,   74,   74,   74,   74,   74,   74,   77,   77,
      184,   77,   77,   77,   77,   77,   77,   77,   77,   77,
       72,   72,   72,   72,   72,   72,   72,   72,   72,   72,
       72,   72,   94,   94,   94,   94,   94,   94,   94,   94,
       94,   94,   94,   94,   75,   75,   75,   75,   75,   75,
       75,   75,   75,   75,   75,   75,   97,   97,   97,   97,
       97,   97,   97,   97,   97,   97,   97,   97,   99,  184,

      184,   99,   99,   99,   99,   99,   99,   99,   99,   99,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,  103,  110,  110,  184,  184,  110,  184,  184,  110,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  119,  119,  119,  119,  119,  119,  119,  119,
      119,  119,  119,  119,  122,  122,  122,  122,  122,  122,
      122,  122,  122,  122,  122,  122,  125,  125,  184,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  110,  184,
      110,  110,  120,  120,  120,  120,  120,  120,  120,  120,
      120,  120,  120,  120,  132,  132,  132,  132,  132,  132,

      132,  132,  132,  132,  132,  132,  123,  123,  123,  123,
      123,  123,  123,  123,  123,  123,  123,  123,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  135,
      138,  184,  184,  138,  154,  154,  154,  154,  154,  154,
      154,  154,  154,  154,  154,  154,  160,  160,  160,  160,
      160,  160,  160,  160,  160,  160,  160,  160,  166,  166,
      166,  166,  166,  166,  166,  166,  166,  166,  166,  166,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,    5,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,

      184,  184,  184,  184,  184,  184
    } ;

static yyconst flex_int16_t yy_chk[1807] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    7,    7,    8,    8,    9,    9,   13,
       28,   13,   20,   20,   21,   21,   23,   40,   23,   47,
       44,   48,   48,   62,   13,   14,   14,   48,   28,   49,
       49,   23,   40,   44,   72,   49,   14,   47,   62,   52,
       52,   14,   15,   15,   88,   88,   15,   56,   78,   72,
       15,   15,   15,   15,   66,   15,   15,   52,   15,   15,
       75,   15,   15,   16,   16,   56,   78,   66,   73,   73,
       76,   76,   90,   75,   16,   16,   77,   77,   91,   16,

       26,   26,   81,   26,   81,  102,   73,   90,   76,   96,
       93,   91,   95,   95,   77,   98,   98,   81,   26,   27,
       27,  117,   96,  102,   27,   93,  109,  109,  118,  120,
       95,  131,  123,   98,  121,  121,  117,   27,   29,   29,
      126,  118,  124,  124,  120,  123,  131,  128,  128,   29,
      125,  134,  121,  110,   29,   31,   31,  140,  126,  128,
      124,   31,  133,  133,  134,  136,  136,  139,   31,   99,
      140,   80,   31,   59,   31,   31,   32,   32,   57,   32,
      133,   32,  139,  136,   46,  179,  179,  181,  181,   41,
       36,   33,   30,   25,   32,   35,   35,  179,   22,  181,

       18,   35,   17,   35,   35,   35,   35,   12,   35,   35,
       10,    5,   35,    0,   35,   35,   39,   39,    0,   39,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   39,   42,   42,    0,   42,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   42,   43,   43,    0,    0,    0,   43,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   43,   45,   45,    0,    0,    0,   45,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   45,   53,   53,    0,   53,    0,   53,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       53,   54,   54,    0,   54,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   54,
       55,   55,    0,    0,    0,   55,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   55,   58,
        0,    0,    0,   58,   58,   58,   58,    0,   58,   58,
        0,    0,   58,    0,   58,   58,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   63,
       63,    0,   63,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,   63,   64,   64,
        0,   64,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   64,   65,   65,    0,
       65,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   65,   67,   67,    0,    0,
        0,   67,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   67,   68,   68,    0,    0,    0,
       68,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   68,   69,   69,    0,    0,    0,   69,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,   69,   71,   71,    0,   71,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   71,   74,   74,    0,    0,    0,   74,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       74,   82,    0,    0,   82,    0,    0,    0,   82,    0,
        0,   82,   83,    0,    0,   83,    0,    0,    0,   83,
        0,    0,   83,   85,   85,   85,    0,    0,    0,    0,
        0,    0,   85,    0,    0,    0,    0,   85,   85,    0,
        0,   85,   87,    0,    0,   87,    0,    0,    0,   87,
        0,    0,   87,   89,   89,   89,    0,    0,    0,    0,

        0,    0,   89,    0,    0,    0,    0,   89,   89,    0,
        0,   89,   94,   94,    0,   94,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       94,   97,   97,    0,    0,    0,   97,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   97,
      100,  100,    0,  100,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  100,  101,
      101,    0,    0,    0,  101,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  101,  103,    0,
        0,  103,    0,    0,    0,  103,    0,    0,  103,  104,

        0,    0,  104,    0,    0,    0,  104,    0,    0,  104,
      105,  105,  105,    0,    0,    0,    0,    0,    0,  105,
        0,    0,    0,    0,  105,  105,    0,    0,  105,  106,
        0,    0,  106,    0,    0,    0,  106,    0,    0,  106,
      107,  107,    0,    0,    0,    0,    0,    0,    0,    0,
      107,    0,    0,  107,    0,    0,    0,  107,    0,    0,
      107,  108,  108,  108,    0,    0,    0,    0,    0,    0,
      108,    0,    0,    0,    0,  108,  108,    0,    0,  108,
      111,    0,    0,  111,    0,    0,    0,  111,    0,    0,
      111,  112,    0,    0,  112,    0,    0,    0,  112,    0,

        0,  112,  114,    0,    0,  114,    0,    0,    0,  114,
        0,    0,  114,  119,  119,    0,  119,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  119,  122,  122,    0,    0,    0,  122,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      122,  132,  132,    0,  132,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  132,
      135,  135,    0,    0,    0,  135,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  135,  137,
        0,    0,  137,    0,    0,    0,  137,    0,    0,  137,

      138,  138,  138,  138,  138,  138,  138,  138,  138,  138,
      138,  138,  138,  138,  138,  138,  138,  138,  138,  138,
      138,  138,  138,  141,  141,  141,  141,  141,  141,  141,
      141,  141,  141,  141,  141,  141,  141,  141,  141,  141,
      141,  141,  141,  141,  141,  141,  142,    0,    0,  142,
        0,    0,    0,  142,    0,    0,  142,  143,    0,    0,
      143,    0,    0,    0,  143,    0,    0,  143,  144,  144,
      144,    0,    0,    0,    0,    0,    0,  144,    0,    0,
        0,    0,  144,  144,    0,    0,  144,  146,    0,    0,
      146,    0,    0,    0,  146,    0,    0,  146,  147,  147,

      147,    0,    0,    0,    0,    0,    0,  147,    0,    0,
        0,    0,  147,  147,    0,    0,  147,  148,    0,    0,
      148,    0,    0,    0,  148,    0,    0,  148,  149,    0,
        0,  149,    0,    0,    0,  149,    0,    0,  149,  150,
      150,  150,    0,    0,    0,    0,    0,    0,  150,    0,
        0,    0,    0,  150,  150,    0,    0,  150,  152,    0,
        0,  152,    0,    0,    0,  152,    0,    0,  152,  153,
      153,  153,    0,    0,    0,    0,    0,    0,  153,    0,
        0,    0,    0,  153,  153,    0,    0,  153,  154,    0,
        0,  154,    0,    0,    0,  154,    0,    0,  154,  155,

        0,    0,  155,    0,    0,    0,  155,    0,    0,  155,
      156,  156,  156,    0,    0,    0,    0,    0,    0,  156,
        0,    0,    0,    0,  156,  156,    0,    0,  156,  157,
        0,    0,  157,    0,    0,    0,  157,    0,    0,  157,
      158,  158,    0,    0,    0,    0,    0,    0,    0,    0,
      158,    0,    0,  158,    0,    0,    0,  158,    0,    0,
      158,  159,  159,  159,    0,    0,    0,    0,    0,    0,
      159,    0,    0,    0,    0,  159,  159,    0,    0,  159,
      160,    0,    0,  160,    0,    0,    0,  160,    0,    0,
      160,  161,    0,    0,  161,    0,    0,    0,  161,    0,

        0,  161,  163,    0,    0,  163,    0,    0,    0,  163,
        0,    0,  163,  166,    0,    0,  166,    0,    0,    0,
      166,    0,    0,  166,  167,    0,    0,  167,    0,    0,
        0,  167,    0,    0,  167,  168,  168,  168,    0,    0,
        0,    0,    0,    0,  168,    0,    0,    0,    0,  168,
      168,    0,    0,  168,  169,    0,    0,  169,    0,    0,
        0,  169,    0,    0,  169,  170,  170,    0,    0,    0,
        0,    0,    0,    0,    0,  170,    0,    0,  170,    0,
        0,    0,  170,    0,    0,  170,  171,  171,  171,    0,
        0,    0,    0,    0,    0,  171,    0,    0,    0,    0,

      171,  171,    0,    0,  171,  172,    0,    0,  172,    0,
        0,    0,  172,    0,    0,  172,  173,    0,    0,  173,
        0,    0,    0,  173,    0,    0,  173,  175,    0,    0,
      175,    0,    0,    0,  175,    0,    0,  175,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      186,  186,    0,    0,  186,    0,    0,  186,  187,  187,
        0,    0,  187,  188,    0,    0,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  189,  189,  189,    0,  189,
      189,    0,  189,  189,  189,  189,  190,    0,  190,  190,
      191,    0,  191,    0,    0,  191,  191,    0,  191,  192,

      192,  192,  192,  192,  192,  192,  192,  192,  192,  192,
      192,  193,  193,  193,  193,  193,  193,  193,  193,  193,
      193,  193,  193,  194,  194,    0,  194,  194,  194,  194,
      194,  194,  194,  194,  194,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  196,  196,  196,
        0,  196,  196,  197,    0,    0,  197,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  200,  200,  200,  200,  200,  200,  200,  200,  200,
      200,  200,  200,  201,  201,  201,  201,  201,  201,  201,

      201,  201,  201,  201,  201,  202,    0,  202,    0,    0,
      202,  202,    0,  202,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  204,  204,  204,  204,
      204,  204,  204,  204,  204,  204,  204,  204,  205,  205,
        0,  205,  205,  205,  205,  205,  205,  205,  205,  205,
      206,  206,  206,  206,  206,  206,  206,  206,  206,  206,
      206,  206,  207,  207,  207,  207,  207,  207,  207,  207,
      207,  207,  207,  207,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  209,  209,  209,  209,
      209,  209,  209,  209,  209,  209,  209,  209,  210,    0,

        0,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  212,  212,    0,    0,  212,    0,    0,  212,
      213,  213,  213,  213,  213,  213,  213,  213,  213,  213,
      213,  213,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  215,  215,  215,  215,  215,  215,
      215,  215,  215,  215,  215,  215,  216,  216,    0,  216,
      216,  216,  216,  216,  216,  216,  216,  216,  217,    0,
      217,  217,  218,  218,  218,  218,  218,  218,  218,  218,
      218,  218,  218,  218,  219,  219,  219,  219,  219,  219,

      219,  219,  219,  219,  219,  219,  220,  220,  220,  220,
      220,  220,  220,  220,  220,  220,  220,  220,  221,  221,
      221,  221,  221,  221,  221,  221,  221,  221,  221,  221,
      222,    0,    0,  222,  223,  223,  223,  223,  223,  223,
      223,  223,  223,  223,  223,  223,  224,  224,  224,  224,
      224,  224,  224,  224,  224,  224,  224,  224,  225,  225,
      225,  225,  225,  225,  225,  225,  225,  225,  225,  225,
      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,
      226,  226,  184,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,

      184,  184,  184,  184,  184,  184
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "../../../gstreamer-1.16.2/gst/parse/parse.l"
#line 2 "../../../gstreamer-1.16.2/gst/parse/parse.l"
#include "../gst_private.h"

#include <math.h>
#include <string.h>

#include <glib/gprintf.h>

#include "types.h"
#include "../gstinfo.h"
#include "../gsturi.h"
#include "grammar.tab.h"

#ifdef malloc
#undef malloc
#endif

#ifdef free
#undef free
#endif

#ifdef realloc
#undef realloc
#endif

#define malloc g_malloc
#define free g_free
#define realloc g_realloc

/* Override the default ECHO so as to avoid fortify warnings. Ignore the
   embedded-NUL case for now. We know yytext is NUL-terminated. */
#define ECHO g_fprintf(yyout, "%s", yytext)

#ifdef G_HAVE_ISO_VARARGS
#define PRINT(...) GST_CAT_DEBUG (GST_CAT_PIPELINE, "flex: " __VA_ARGS__)
#elif defined(G_HAVE_GNUC_VARARGS)
#define PRINT(args...) GST_CAT_DEBUG (GST_CAT_PIPELINE, "flex: " args)
#else
static inline void
PRINT (const char *format, ...)
{
  va_list varargs;

  va_start (varargs, format);
  GST_CAT_LEVEL_LOG_valist (GST_CAT_PIPELINE, GST_LEVEL_DEBUG, NULL,
    format, varargs);
  va_end (varargs);
}
#endif

/* we must do this here, because nearly everything matches a {_string} */ 
/* get pad/element references and stuff with dots right */
/* links */

#define YY_NO_INPUT 1
#line 964 "lex.priv_gst_parse_yy.c"

#define INITIAL 0
#define value 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    yy_size_t yy_n_chars;
    yy_size_t yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int priv_gst_parse_yylex_init (yyscan_t* scanner);

int priv_gst_parse_yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int priv_gst_parse_yylex_destroy (yyscan_t yyscanner );

int priv_gst_parse_yyget_debug (yyscan_t yyscanner );

void priv_gst_parse_yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE priv_gst_parse_yyget_extra (yyscan_t yyscanner );

void priv_gst_parse_yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *priv_gst_parse_yyget_in (yyscan_t yyscanner );

void priv_gst_parse_yyset_in  (FILE * _in_str ,yyscan_t yyscanner );

FILE *priv_gst_parse_yyget_out (yyscan_t yyscanner );

void priv_gst_parse_yyset_out  (FILE * _out_str ,yyscan_t yyscanner );

yy_size_t priv_gst_parse_yyget_leng (yyscan_t yyscanner );

char *priv_gst_parse_yyget_text (yyscan_t yyscanner );

int priv_gst_parse_yyget_lineno (yyscan_t yyscanner );

void priv_gst_parse_yyset_lineno (int _line_number ,yyscan_t yyscanner );

int priv_gst_parse_yyget_column  (yyscan_t yyscanner );

void priv_gst_parse_yyset_column (int _column_no ,yyscan_t yyscanner );

YYSTYPE * priv_gst_parse_yyget_lval (yyscan_t yyscanner );

void priv_gst_parse_yyset_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int priv_gst_parse_yywrap (yyscan_t yyscanner );
#else
extern int priv_gst_parse_yywrap (yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int priv_gst_parse_yylex \
               (YYSTYPE * yylval_param ,yyscan_t yyscanner);

#define YY_DECL int priv_gst_parse_yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			priv_gst_parse_yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				priv_gst_parse_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		priv_gst_parse_yy_load_buffer_state(yyscanner );
		}

	{
#line 87 "../../../gstreamer-1.16.2/gst/parse/parse.l"


#line 1241 "lex.priv_gst_parse_yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 185 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 184 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 89 "../../../gstreamer-1.16.2/gst/parse/parse.l"
{
    /* "=" */
    PRINT ("ASSIGNMENT: %s", yytext);
    yylval->ss = gst_parse_strdup (yytext);
    BEGIN (INITIAL);
    return ASSIGNMENT;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 97 "../../../gstreamer-1.16.2/gst/parse/parse.l"
{
    yytext++;
    PRINT ("PADREF: %s", yytext);
    yylval->ss = gst_parse_strdup (yytext);
    BEGIN (INITIAL);
    return PADREF;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 105 "../../../gstreamer-1.16.2/gst/parse/parse.l"
{
    PRINT ("REF: %s", yytext);
    yylval->ss = gst_parse_strdup (yytext);
    BEGIN (INITIAL);
    return REF;
}
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 112 "../../../gstreamer-1.16.2/gst/parse/parse.l"
{
    gchar *pos = yytext;
    while (!g_ascii_isspace (*pos) && (*pos != '.')) pos++;
    *pos = '\0';
    PRINT ("BINREF: %s", yytext);
    yylval->ss = gst_parse_strdup (yytext);
    BEGIN (INITIAL);
    return BINREF;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 122 "../../../gstreamer-1.16.2/gst/parse/parse.l"
{
    PRINT ("IDENTIFIER: %s", yytext);
    yylval->ss = gst_parse_strdup (yytext);
    BEGIN (INITIAL);
    return IDENTIFIER;
}
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 129 "../../../gstreamer-1.16.2/gst/parse/parse.l"
{
    gchar *c = yytext;
    gchar op;
    gboolean link_all;

    PRINT ("LINK: %s", yytext);
    /* First char is a link operator */
    link_all = (*c == ':');
    c++;
    if (*c) {
      while (g_ascii_isspace (*c)) c++;
      c = yylval->ss = gst_parse_strdup (c);
      while (*c) c++;
      /* Last non-space char is a link operator */
      op = *--c;
      if (op != '!' && op != ':')
	g_assert_not_reached ();
      if (op == ':')
        link_all = TRUE;

      /* Walk backward past whitespaces - what remains
       * is a filter caps string, or empty */
      while (g_ascii_isspace (*--c));
      *++c = '\0';
    } else {
      yylval->ss = NULL;
    }
    BEGIN (INITIAL);
    return link_all ? LINK_ALL : LINK;
}
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 159 "../../../gstreamer-1.16.2/gst/parse/parse.l"
{
  PRINT ("URL: %s", yytext);
  yylval->ss = g_strdup (yytext);
  gst_parse_unescape (yylval->ss);
  BEGIN (INITIAL);
  return PARSE_URL;
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 167 "../../../gstreamer-1.16.2/gst/parse/parse.l"
{ PRINT ("OPERATOR: [%s]", yytext); return *yytext; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 169 "../../../gstreamer-1.16.2/gst/parse/parse.l"
{ PRINT ("SPACE: [%s]", yytext); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 171 "../../../gstreamer-1.16.2/gst/parse/parse.l"
{
    PRINT ("Invalid Lexer element: %s\n", yytext);
    return *yytext;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 176 "../../../gstreamer-1.16.2/gst/parse/parse.l"
ECHO;
	YY_BREAK
#line 1422 "lex.priv_gst_parse_yy.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(value):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * priv_gst_parse_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( priv_gst_parse_yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of priv_gst_parse_yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	yy_size_t number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					priv_gst_parse_yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			priv_gst_parse_yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) priv_gst_parse_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 185 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 185 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 184);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yy_size_t offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					priv_gst_parse_yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( priv_gst_parse_yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void priv_gst_parse_yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        priv_gst_parse_yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            priv_gst_parse_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	priv_gst_parse_yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	priv_gst_parse_yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void priv_gst_parse_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		priv_gst_parse_yypop_buffer_state();
	 *		priv_gst_parse_yypush_buffer_state(new_buffer);
     */
	priv_gst_parse_yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	priv_gst_parse_yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (priv_gst_parse_yywrap()) processing, but the only time this flag
	 * is looked at is after priv_gst_parse_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void priv_gst_parse_yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE priv_gst_parse_yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) priv_gst_parse_yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in priv_gst_parse_yy_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) priv_gst_parse_yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in priv_gst_parse_yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	priv_gst_parse_yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with priv_gst_parse_yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void priv_gst_parse_yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		priv_gst_parse_yyfree((void *) b->yy_ch_buf ,yyscanner );

	priv_gst_parse_yyfree((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a priv_gst_parse_yyrestart() or at EOF.
 */
    static void priv_gst_parse_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	priv_gst_parse_yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then priv_gst_parse_yy_init_buffer was _probably_
     * called from priv_gst_parse_yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void priv_gst_parse_yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		priv_gst_parse_yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void priv_gst_parse_yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	priv_gst_parse_yyensure_buffer_stack(yyscanner);

	/* This block is copied from priv_gst_parse_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from priv_gst_parse_yy_switch_to_buffer. */
	priv_gst_parse_yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void priv_gst_parse_yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	priv_gst_parse_yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		priv_gst_parse_yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void priv_gst_parse_yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)priv_gst_parse_yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in priv_gst_parse_yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)priv_gst_parse_yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in priv_gst_parse_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE priv_gst_parse_yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) priv_gst_parse_yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in priv_gst_parse_yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	priv_gst_parse_yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to priv_gst_parse_yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       priv_gst_parse_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE priv_gst_parse_yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return priv_gst_parse_yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to priv_gst_parse_yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE priv_gst_parse_yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) priv_gst_parse_yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in priv_gst_parse_yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = priv_gst_parse_yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in priv_gst_parse_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE priv_gst_parse_yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int priv_gst_parse_yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int priv_gst_parse_yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *priv_gst_parse_yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *priv_gst_parse_yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
yy_size_t priv_gst_parse_yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *priv_gst_parse_yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void priv_gst_parse_yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void priv_gst_parse_yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "priv_gst_parse_yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void priv_gst_parse_yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "priv_gst_parse_yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see priv_gst_parse_yy_switch_to_buffer
 */
void priv_gst_parse_yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void priv_gst_parse_yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int priv_gst_parse_yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void priv_gst_parse_yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * priv_gst_parse_yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void priv_gst_parse_yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* priv_gst_parse_yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int priv_gst_parse_yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) priv_gst_parse_yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* priv_gst_parse_yylex_init_extra has the same functionality as priv_gst_parse_yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to priv_gst_parse_yyalloc in
 * the yyextra field.
 */

int priv_gst_parse_yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    priv_gst_parse_yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) priv_gst_parse_yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    priv_gst_parse_yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from priv_gst_parse_yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * priv_gst_parse_yylex_init()
     */
    return 0;
}

/* priv_gst_parse_yylex_destroy is for both reentrant and non-reentrant scanners. */
int priv_gst_parse_yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		priv_gst_parse_yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		priv_gst_parse_yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	priv_gst_parse_yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        priv_gst_parse_yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * priv_gst_parse_yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    priv_gst_parse_yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *priv_gst_parse_yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return (void *) malloc( size );
}

void *priv_gst_parse_yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void priv_gst_parse_yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see priv_gst_parse_yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 176 "../../../gstreamer-1.16.2/gst/parse/parse.l"


/* A Bison parser, made by GNU Bison 3.4.1.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Undocumented macros, especially those whose name start with YY_,
   are private implementation details.  Do not rely on them.  */

#ifndef YY_PRIV_GST_PARSE_YY_GRAMMAR_TAB_H_INCLUDED
# define YY_PRIV_GST_PARSE_YY_GRAMMAR_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int priv_gst_parse_yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    PARSE_URL = 258,
    IDENTIFIER = 259,
    REF = 260,
    PADREF = 261,
    BINREF = 262,
    ASSIGNMENT = 263,
    LINK = 264,
    LINK_ALL = 265
  };
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 750 "../../../gstreamer-1.16.2/gst/parse/grammar.y"

    gchar *ss;
    chain_t *cc;
    link_t *ll;
    reference_t rr;
    GstElement *ee;
    GSList *pp;
    graph_t *gg;

#line 78 "grammar.tab.h"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif



int priv_gst_parse_yyparse (void *scanner, graph_t *graph);

#endif /* !YY_PRIV_GST_PARSE_YY_GRAMMAR_TAB_H_INCLUDED  */

